#ifndef _SingleEvent_
#define _SingleEvent_

//////////////////////////////////////////////////////////////////////////
//                                                                      //
// SingleEvent                                                          //
//                                                                      //
// Description of the single event and dcs monitor parameters           //
//                                                                      //
//////////////////////////////////////////////////////////////////////////

#include "TObject.h"
#include "TClonesArray.h"
#include "Cluster.h"

class Cluster;

class SingleEvent : public TObject {

 private:
  Int_t          fNCluster;      //Total number of cluster in acquisition
  Double_t       fTemperature;   //Temperature
  Double_t       fPressure;      //Atmospheric Pressure
  Double_t       fDJT;           //Difference (in J.day) between "single part."                                 //acquisistion and nearest temp. measurement
  Double_t       fDJP;           //Difference (in J.day) between "single part."                                 //acquisistion and nearest press. measurement
  Double_t       fDeltaTAcq ;     //Time difference between 2 acquisition
  TClonesArray  *fClusters;       //->array with all data depending on cluster

  static TClonesArray *fgClusters;

 public:
  SingleEvent();
  virtual ~SingleEvent();
  void          SetNCluster(Int_t n) { fNCluster = n; }
  void          SetTemperature(Double_t t) { fTemperature = t; }
  void          SetDJT(Double_t DJT) { fDJT = DJT; }
  void          SetPressure(Double_t p) { fPressure = p; }
  void          SetDJP(Double_t DJP) { fDJP = DJP; }
  void          SetDeltaTAcq(Double_t DTAQ) { fDeltaTAcq = DTAQ; }
  Cluster *AddCluster(Double_t dJNclu, Double_t Vpd);

  Int_t          GetNCluster() { return fNCluster; }
  Double_t       GetTemperature() { return fTemperature; }
  TClonesArray  *GetClusters() const {return fClusters;}

  ClassDef(SingleEvent,1)  //SingleEvent structure
};




#endif
